@@ -1,6 +1,6 @@
 package NetStumbler::Wap;
 
-use 5.008003;
+use 5.008000;
 use strict;
 use warnings;
 
@@ -11,16 +11,17 @@ our @ISA = qw(Exporter);
 #
 # We do not Export anything
 #
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 Object Methods
 
-=head2 NetStumbler::Wap->new()
+=head2 new()
 
 Returns a new Wap object. NOTE: this method may take some time to execute
 as it loads the list into memory at construction time
 
 =cut
+
 sub new
 {
     my $proto = shift;
@@ -47,7 +48,71 @@ sub new
     return $self;
 }
 
-=head2 NetStumbler::WapLib->getVendorForBBSID ($mac)
+=head2 isAdhoc($flags)
+
+Params:
+	-number 801.11 Capability flags
+Returns:
+	true is the flags indicate the access point is in adhoc mode
+Example:
+	if($obj->isAdhoc($flags))
+	{
+		# do something here
+	}
+
+=cut
+
+sub isAdhoc
+{
+
+	my $self = shift;
+	my $flags = shift;
+	return $flags & 0x0002;
+}
+
+=head2 isInfrascruture($flags)
+
+Params:
+	-number 801.11 Capability flags
+Returns:
+	true is the flags indicate the access point is in infrastructure mode
+Example:
+	if($obj->isInfrascructure($flags))
+	{
+		# do something here
+	}
+
+=cut
+
+sub isInfrastructure
+{
+	my $self = shift;
+	my $flags = shift;
+	return !isAdhoc($flags);
+}
+
+=head2 hasWEP($flags)
+
+Params:
+	-number 801.11 Capability flags
+Returns:
+	true is the flags indicate the access point has WEP enabled
+Example:
+	if($obj->hasWEP($flags))
+	{
+		# do something here
+	}
+
+=cut
+
+sub hasWEP
+{
+	my $flags = shift;
+	return $flags & 0x0010;
+}
+
+
+=head2 getVendorForBBSID ($mac)
 
 Determine the vendor or a nic by the MAC prefix
 The argument should be a mac address in the format of
@@ -503,7 +568,7 @@ __DATA__
 __END__
 # Below is stub documentation for your module. You'd better edit it!
 
-=head1 NetStumbler::Wap
+=head1 NAME
 
 NetStumbler::Wap - Wap tools for NetStumbler
 
@@ -525,7 +590,7 @@ None by default.
 
 =head1 SEE ALSO
 
-<a href="http://idogan.istanbul.edu.tr/oui_full.html">OUI</a> database
+http://idogan.istanbul.edu.tr/oui_full.html OUI database
 All the items in this list were generated by parsing the oui database
 
 =head1 AUTHOR
